@@ -10,7 +10,6 @@ from .ticket import Ticket
 class EchoWorker(Worker):
     def __init__(self) -> None:
         super(EchoWorker, self).__init__()
-        self.busy = False
 
     @property
     def name(self) -> str:
@@ -20,10 +19,6 @@ class EchoWorker(Worker):
     def duties(self) -> Tuple:
         return ("echo",)
 
-    @property
-    def is_busy(self) -> bool:
-        return self.busy
-
     @property
     def status(self) -> Dict:
         return {}
