@@ -1,5 +1,5 @@
 class YumError(Exception):
-    def __init__(self, code: int = 500, reason: str = "Unknown error") -> None:
+    def __init__(self, code: int = 500, reason: str = "Unknown Error") -> None:
         super(YumError, self).__init__()
         self.code = code
         self.reason = reason
@@ -21,10 +21,10 @@ class YumTimeout(YumError):
 
 
 class YumBadRequest(YumError):
-    def __init__(self, reason: str = "not found") -> None:
+    def __init__(self, reason: str = "Bad Request") -> None:
         super(YumBadRequest, self).__init__(400, reason)
 
 
 class YumNotFound(YumError):
-    def __init__(self, reason: str = "not found") -> None:
+    def __init__(self, reason: str = "Not Found") -> None:
         super(YumNotFound, self).__init__(404, reason)
