@@ -1,8 +1,8 @@
 from abc import ABC, abstractmethod
 from uuid import uuid4
 
-from typing import Dict, Tuple
-from .ticket import Ticket
+from typing import Tuple
+from .ticket import Ticket, Feedback
 
 
 class Worker(ABC):
@@ -34,11 +34,6 @@ class Worker(ABC):
     def duties(self) -> Tuple:
         pass
 
-    @property
-    @abstractmethod
-    def status(self) -> Dict:
-        pass
-
     @abstractmethod
     def setup(self) -> None:
         pass
@@ -48,5 +43,5 @@ class Worker(ABC):
         pass
 
     @abstractmethod
-    def doing(self, ticket: Ticket) -> Ticket:
+    def doing(self, ticket: Ticket) -> Feedback:
         pass
